pub struct SrcRef {
pub range: Span,
pub at: LineCol,
pub source_hash: HashId,
}Expand description
Reference into a source file.
Hint: Source file is not part of SrcRef and must be provided from outside
Fields
range: SpanRange in bytes
at: LineColLine and column
source_hash: HashIdHash of the source code file to map SrcRef -> SourceFile
Implementations
Sourceimpl SrcRef
impl SrcRef
Sourcepub fn new(range: Range<usize>, at: LineCol, source_hash: HashId) -> Self
pub fn new(range: Range<usize>, at: LineCol, source_hash: HashId) -> Self
Create new SrcRef
range: Position in fileline: Line number within filecol: Column number within file
pub fn none() -> Self
Sourcepub fn as_miette_span(&self) -> Option<SourceSpan>
pub fn as_miette_span(&self) -> Option<SourceSpan>
Return a span for the source reference as expected by miette
pub fn is_none(&self) -> bool
pub fn is_some(&self) -> bool
Sourcepub fn is_overlapping(&self, other: &Self) -> bool
pub fn is_overlapping(&self, other: &Self) -> bool
Check if two source refs are overlapping.
This means they must have the same non-zero source file hash and its ranges must overlap.
Sourcepub fn with_line_offset(&self, line_offset: u32) -> Self
pub fn with_line_offset(&self, line_offset: u32) -> Self
Return a reference with a given line offset.
Sourcepub fn source_hash(&self) -> u64
pub fn source_hash(&self) -> u64
return source file hash
0if notSrcRefInneris noneu64ifSrcRefInneris some
This is used to map SrcRef -> SourceFile
Sourcepub fn source_slice<'a>(&self, src: &'a str) -> &'a str
pub fn source_slice<'a>(&self, src: &'a str) -> &'a str
Return slice to code base.
Sourcepub fn merge(lhs: &impl SrcReferrer, rhs: &impl SrcReferrer) -> SrcRef
pub fn merge(lhs: &impl SrcReferrer, rhs: &impl SrcReferrer) -> SrcRef
Merge two SrcRef into a single one.
SrcRef::none() is returned if:
- ranges not in correct order (warning in log),
- references are not in the same file (warning in log),
- or
lhsandrhsare bothNone.
Sourcepub fn merge_all<S: SrcReferrer>(referrers: impl Iterator<Item = S>) -> SrcRef
pub fn merge_all<S: SrcReferrer>(referrers: impl Iterator<Item = S>) -> SrcRef
Merge all given source references to one
All given source references must have the same hash otherwise panics!